Murano Dashboard Style Commandments
===================================

*- Step 1: Read the OpenStack Style Commandments
  http://docs.openstack.org/developer/hacking/

* Step 2: Read [hacking] section in tox.ini to find the list of names which
  can be imported directly without triggering the "H302: import only modules"
  flake8 warning

* Step 3: Read on
